==> ccchh-dooris-widget_0.1.2.tar.gz: ccchh-dooris-widget-0.1.2/src/ccchh-dooris-widget.h <==
/* ccchh_dooris_desktop_widget.h */

#ifndef _CCCHH_DOORIS_DESKTOP_WIDGET
#define _CCCHH_DOORIS_DESKTOP_WIDGET

#include <libhildondesktop/libhildondesktop.h>
#include <conic.h> /* libconic - Internet Connectivity library */

G_BEGIN_DECLS

#define TYPE_CCCHH_DOORIS_DESKTOP_WIDGET ccchh_dooris_desktop_widget_get_type()

#define CCCHH_DOORIS_DESKTOP_WIDGET(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CCCHH_DOORIS_DESKTOP_WIDGET, CCCHHDoorIsDesktopWidget))

#define CCCHH_DOORIS_DESKTOP_WIDGET_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CCCHH_DOORIS_DESKTOP_WIDGET, CCCHHDoorIsDesktopWidgetClass))

#define IS_CCCHH_DOORIS_DESKTOP_WIDGET(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CCCHH_DOORIS_DESKTOP_WIDGET))

#define IS_CCCHH_DOORIS_DESKTOP_WIDGET_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CCCHH_DOORIS_DESKTOP_WIDGET))

#define CCCHH_DOORIS_DESKTOP_WIDGET_GET_CLASS(obj) \
  (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CCCHH_DOORIS_DESKTOP_WIDGET, CCCHHDoorIsDesktopWidgetClass))

typedef enum {
	DOORIS_OPEN,
	DOORIS_CLOSED,
	DOORIS_FNORD
} dooris_state_t;

typedef struct {
	// external handlers
	HDHomePluginItem parent;
	gint timeout_handler;
	ConIcConnection *connection;
	gint connection_handler;

	// internal state
	cairo_surface_t *image_current;
	gboolean force_banner;
	gboolean updating;
	gboolean connected;
	gdouble current_alpha;

	// door state information
	dooris_state_t last_state;
	dooris_state_t last_known_state;
	dooris_state_t current_state;
	gulong last_change_ts;
	gulong last_report_ts;

	// configuration settings
	guint update;
	gchar *url;
	gboolean notify;
	gboolean use_connection;
	gboolean force_connection;

	// used by the settings dialog
	GtkWidget *settings_window;
	GtkWidget *url_entry;
	GtkWidget *update_picker;
	GtkWidget *notify_button;
	GtkWidget *connection_button;
	GtkWidget *connforce_button;
} CCCHHDoorIsDesktopWidget;

typedef struct {
	HDHomePluginItemClass parent_class;
} CCCHHDoorIsDesktopWidgetClass;

GType ccchh_dooris_desktop_widget_get_type (void);

CCCHHDoorIsDesktopWidget* ccchh_dooris_desktop_widget_new (void);

// timer callback function
static gboolean
ccchh_dooris_desktop_widget_on_timeout (gpointer data);

// connection event callback function
static void
ccchh_dooris_desktop_widget_connection_event(ConIcConnection *connection,
  ConIcConnectionEvent *event, gpointer user_data);

G_END_DECLS

#endif /* _CCCHH_DOORIS_DESKTOP_WIDGET */

==> ccchh-dooris-widget_0.1.5.tar.gz: ccchh-dooris-widget-0.1.5/src/ccchh-dooris-widget.h <==
/* ccchh_dooris_desktop_widget.h */

#ifndef _CCCHH_DOORIS_DESKTOP_WIDGET
#define _CCCHH_DOORIS_DESKTOP_WIDGET


// max download size
#define MAX_HTTP_SIZE 1024

// minimum/maximum selectable update interval
// in minutes
#define UPDATE_INTERVAL_MIN 5
#define UPDATE_INTERVAL_MAX 1440

// paths to icon files
#define IMAGE_DOORIS_OPEN           DATADIR"/dooris_open.png"
#define IMAGE_DOORIS_CLOSED         DATADIR"/dooris_closed.png"
#define IMAGE_DOORIS_FNORD          DATADIR"/dooris_fnord.png"
#define IMAGE_OVERLAY_DISCONNECTED  DATADIR"/dooris_notavail.png"

// widget size
#define IMAGE_WIDGET_WIDTH  102
#define IMAGE_WIDGET_HEIGHT 72

// transparency
#define IMAGE_ALPHA_NORMAL      1.0
#define IMAGE_ALPHA_HIGHLIGHT   0.65


G_BEGIN_DECLS

#include <libhildondesktop/libhildondesktop.h>
#include <conic.h> /* libconic - Internet Connectivity library */

#define TYPE_CCCHH_DOORIS_DESKTOP_WIDGET ccchh_dooris_desktop_widget_get_type()

#define CCCHH_DOORIS_DESKTOP_WIDGET(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CCCHH_DOORIS_DESKTOP_WIDGET, CCCHHDoorIsDesktopWidget))

#define CCCHH_DOORIS_DESKTOP_WIDGET_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CCCHH_DOORIS_DESKTOP_WIDGET, CCCHHDoorIsDesktopWidgetClass))

#define IS_CCCHH_DOORIS_DESKTOP_WIDGET(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CCCHH_DOORIS_DESKTOP_WIDGET))

#define IS_CCCHH_DOORIS_DESKTOP_WIDGET_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CCCHH_DOORIS_DESKTOP_WIDGET))

#define CCCHH_DOORIS_DESKTOP_WIDGET_GET_CLASS(obj) \
  (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CCCHH_DOORIS_DESKTOP_WIDGET, CCCHHDoorIsDesktopWidgetClass))

typedef enum {
	DOORIS_OPEN,
	DOORIS_CLOSED,
	DOORIS_FNORD
} dooris_state_t;

typedef struct {
	// external handlers
	HDHomePluginItem parent;
	gint timeout_handler;
	ConIcConnection *connection;
	gint connection_handler;

	// internal state
	cairo_surface_t *image_current;
	gboolean force_banner;
	gboolean connected;
	gchar *disconnecting;
	gdouble current_alpha;
	GStaticMutex button_lock;
	GStaticMutex fetch_lock;

	// door state information
	dooris_state_t last_state;
	dooris_state_t last_known_state;
	dooris_state_t current_state;
	gulong last_change_ts;
	gulong last_report_ts;

	// configuration settings
	guint update;
	gchar *url;
	gboolean notify;
	gboolean use_connection;
	gboolean force_connection;

	// used by the settings dialog
	GtkWidget *settings_window;
	GtkWidget *url_entry;
	GtkWidget *update_picker;
	GtkWidget *notify_button;
	GtkWidget *connection_button;
	GtkWidget *connforce_button;

	// gvfs structures
	GnomeVFSAsyncHandle *gvfs_handle;
	gchar *gvfs_input_buffer;

} CCCHHDoorIsDesktopWidget;

typedef struct {
	HDHomePluginItemClass parent_class;
} CCCHHDoorIsDesktopWidgetClass;

GType ccchh_dooris_desktop_widget_get_type (void);

CCCHHDoorIsDesktopWidget* ccchh_dooris_desktop_widget_new (void);

// timer callback function
static gboolean
ccchh_dooris_desktop_widget_on_timeout (gpointer data);

// connection event callback function
static void
ccchh_dooris_desktop_widget_connection_event(ConIcConnection *connection,
	ConIcConnectionEvent *event, gpointer user_data);


static void
fetch_update_async_open_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
	gpointer data);

static void
fetch_update_async_read_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
	gpointer buffer, GnomeVFSFileSize bytes_requested, GnomeVFSFileSize bytes_read,
	gpointer data);

static void
fetch_update_async_close_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
	gpointer data);


static void
process_update (CCCHHDoorIsDesktopWidget *self, dooris_state_t new_state,
	gulong new_change_ts, gulong new_report_ts);


static void
force_redraw (CCCHHDoorIsDesktopWidget *self);

static void
show_status_banner (CCCHHDoorIsDesktopWidget *self);

G_END_DECLS

#endif /* _CCCHH_DOORIS_DESKTOP_WIDGET */
